<script setup lang="ts">
import { ref } from "vue";
import ForceChart from "./components/ForceChart.vue";
import GaugeDisplay from "./components/GaugeDisplay.vue";
import TableDisplay from "./components/TableDisplay.vue";
import ThreeDDisplay from "./components/ThreeDDisplay.vue";
import TitleBar from "./components/TitleBar.vue";
import SerialPortConfig from "./components/SerialPortConfig.vue";

const logs = ref<string[]>([]);
// const isSerialPortConnected = ref(false); // 新增：跟踪串口连接状态

const currentDisplay = ref('setting'); // 默认显示曲线图


// async function startPipeServer() {
//   try {
//     const res = await invoke('start_pipe_server_command', {pipeName});
//     console.log(res);
//     logs.value.push('[系统] 数据接收服务已启动');
//     console.log('[系统] 管道服务端已启动');
//     showChart.value = true;
//   } catch (err) {
//     logs.value.push(`[错误] 启动失败: ${err}`);
//   }
// }

// async function sendToPipe() {
//   if (!message.value) return;
  
//   try {
//     const response = await invoke('send_pipe_message', {pipeName, message: message.value });
//     logs.value.push(`[发送] ${message.value}`);
//     logs.value.push(`[接收] ${response}`);
//     message.value = '';
//   } catch (err) {
//     logs.value.push(`[错误] 通信失败: ${err}`);
//   }
// }
// startPipeServer();

const handleConnectionChange = (connected: boolean) => {
  if (connected) {
    currentDisplay.value = 'line';
  }
}
</script>

<template>
  <TitleBar :currentDisplay="currentDisplay"  @select-display="(mode) => currentDisplay = mode" />
  <main class="container">
   

    <div class="display-mode-icons">
      <button :class="['icon-button', { active: currentDisplay === 'setting' }]" @click="currentDisplay = 'setting'" title="串口设置">
        <svg width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round">
          <path d="M12.22 2h-.44a2 2 0 0 0-2 2v.18a2 2 0 0 1-1 1.73l-.43.25a2 2 0 0 1-2 0l-.15-.08a2 2 0 0 0-2.73.73l-.22.38a2 2 0 0 0 .73 2.73l.15.1a2 2 0 0 1 1 1.72v.51a2 2 0 0 1-1 1.74l-.15.09a2 2 0 0 0-.73 2.73l.22.38a2 2 0 0 0 2.73.73l.15-.08a2 2 0 0 1 2 0l.43.25a2 2 0 0 1 1 1.73V20a2 2 0 0 0 2 2h.44a2 2 0 0 0 2-2v-.18a2 2 0 0 1 1-1.73l.43-.25a2 2 0 0 1 2 0l.15.08a2 2 0 0 0 2.73-.73l.22-.39a2 2 0 0 0-.73-2.73l-.15-.08a2 2 0 0 1-1-1.74v-.5a2 2 0 0 1 1-1.74l.15-.09a2 2 0 0 0 .73-2.73l-.22-.38a2 2 0 0 0-2.73-.73l-.15.08a2 2 0 0 1-2 0l-.43-.25a2 2 0 0 1-1-1.73V4a2 2 0 0 0-2-2z"/>
          <circle cx="12" cy="12" r="3"/>
        </svg>
      </button>
      <button :class="['icon-button', { active: currentDisplay === 'line' }]" @click="currentDisplay = 'line'" title="曲线图">
        <svg width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path d="M2 13L8.5 6L13.5 12L19 7L22 10"/><path d="M18 13a2 2 0 1 0 4 0a2 2 0 1 0 -4 0"/></svg>
      </button>
      <button :class="['icon-button', { active: currentDisplay === 'gauge' }]" @click="currentDisplay = 'gauge'" title="仪表盘">
        <svg width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><circle cx="12" cy="12" r="10"/><path d="M12 6v6l4 2"/></svg>
      </button>
      <button :class="['icon-button', { active: currentDisplay === 'table' }]" @click="currentDisplay = 'table'" title="数据表格">
        <svg width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><rect width="20" height="14" x="2" y="7" rx="2"/><path d="M10 12H6"/><path d="M18 12h-4"/><path d="M10 16H6"/><path d="M18 16h-4"/></svg>
      </button>
      <button :class="['icon-button', { active: currentDisplay === '3d' }]" @click="currentDisplay = '3d'" title="3D坐标轴">
        <svg width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path d="M12 2L2 7l10 5l10-5l-10-5z"/><path d="M2 17l10 5l10-5"/><path d="M2 12l10 5l10-5"/></svg>
      </button>
    </div>
    <div class="header-row">
      <h2>Force Sensor Data Visualization</h2>
    </div>
    
    <!-- 显示力传感器数据 -->
    <div  class="chart-wrapper">

      <ForceChart v-if="currentDisplay === 'line'" />
      <GaugeDisplay v-else-if="currentDisplay === 'gauge'" />
      <TableDisplay v-else-if="currentDisplay === 'table'"/>
      <ThreeDDisplay v-else-if="currentDisplay === '3d'" />
      <SerialPortConfig v-else-if="currentDisplay === 'setting'" @connection-change="handleConnectionChange" />
    </div>

 
    
    <!-- <div class="input-group">
      <input 
        v-model="message"
        placeholder="输入测试消息"
        @keyup.enter="sendToPipe"
      />
      <button @click="sendToPipe">发送消息</button>
    </div> -->
    
    <div class="log-container">
      <div v-for="(log, index) in logs" :key="index" class="log-item">
        {{ log }}
      </div>
    </div>
  </main>
</template>

<style scoped>
.control-group {
  margin: 20px 0;
}

.input-group {
  display: flex;
  gap: 10px;
  margin: 20px 20px auto;
  max-width: 500px;
}

.chart-wrapper {
  width: 95%;
  margin: 10px auto;
  background-color: #ffffff;
  border-radius: 8px;
  padding: 12px;
  box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
  height: 580px;
}

.log-container {

  border-radius: 8px;
  height: 34px;
  overflow-y: auto;

}

.log-item {
  padding: 5px 0;
  color: #000;
  font-size: 0.9em;
}

.data-source-switch {
  margin-bottom: 16px;
  display: flex;
  align-items: center;
  gap: 8px;
}

/* Modal Styles */
.modal-overlay {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(0, 0, 0, 0.5);
  display: flex;
  justify-content: center;
  align-items: center;
  z-index: 1000;
}

.modal-content {
  background-color: #fff;
  padding: 20px;
  border-radius: 8px;
  box-shadow: 0 4px 12px rgba(0, 0, 0, 0.15);
  position: relative;
  min-width: 300px;
  max-width: 90%;
}

.close-button {
  position: absolute;
  top: 10px;
  right: 10px;
  background: none;
  border: none;
  font-size: 1.2em;
  cursor: pointer;
  color: #555;
}
</style>

<style>
:root {
  font-family: Inter, Avenir, Helvetica, Arial, sans-serif;
  font-size: 16px;
  line-height: 24px;
  font-weight: 400;

  color: #0f0f0f;
  background-color: #f6f6f6;

  font-synthesis: none;
  text-rendering: optimizeLegibility;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  -webkit-text-size-adjust: 100%;
}

.container {
  margin: 32px 0 0 0;
  display: flex;
  flex-direction: column;
  justify-content: center;
  text-align: center;
  align-items: center;
}

.logo {
  height: 6em;
  padding: 1.5em;
  will-change: filter;
  transition: 0.75s;
}

.logo.tauri:hover {
  filter: drop-shadow(0 0 2em #24c8db);
}

.row {
  display: flex;
  justify-content: center;
}

a {
  font-weight: 500;
  color: #646cff;
  text-decoration: inherit;
}

a:hover {
  color: #535bf2;
}

h1 {
  text-align: center;
}

input,
button {
  border-radius: 8px;
  border: 1px solid transparent;
  padding: 0.6em 1.2em;
  font-size: 1em;
  font-weight: 500;
  font-family: inherit;
  color: #0f0f0f;
  background-color: #ffffff;
  transition: border-color 0.25s;
  box-shadow: 0 2px 2px rgba(0, 0, 0, 0.2);
}

button {
  cursor: pointer;
}

button:hover {
  border-color: #396cd8;
}
button:active {
  border-color: #396cd8;
  background-color: #e8e8e8;
}

input,
button {
  outline: none;
}

#greet-input {
  margin-right: 5px;
}

@media (prefers-color-scheme: dark) {
  :root {
    color: #f6f6f6;
    background-color: #2f2f2f;
  }

  a:hover {
    color: #24c8db;
  }

  input,
  button {
    color: #ffffff;
    background-color: #0f0f0f98;
  }
  button:active {
    background-color: #0f0f0f69;
  }
}

.header-row {
  height: 60px;
  display: flex;
  justify-content: center;
  align-items: center;
  padding: 0 20px;
  color: wheat;
}

.header-row h2 {
  margin: 0;
}

.icon-button {
  width: 28px; /* Slightly larger for icons */
  height: 28px; /* Slightly larger for icons */
  border: none;
  background: rgba(255, 254, 254, 0.7);
  color: rgba(85, 85, 85, 0.7); /* Slightly transparent white */
  display: flex;
  align-items: center;
  justify-content: center;
  border-radius: 4px;
  padding: 0;
  transition: background-color 0.2s, color 0.2s;
  cursor: pointer;
}

.icon-button:hover {
  background-color: rgba(255, 255, 255, 0.1);
  color: black; /* Full white on hover */
}

.icon-button.active {
  color: #3498db; /* Active color */
  background-color: rgba(255, 254, 254, 0.7); /* Slightly different background for active */
}
.display-mode-icons {
  display: flex;
  align-items: center;
  justify-content: center;
  gap: 4px; /* Smaller gap for icons */
  margin-top: -27px; /* Space between icons and window controls */
  width: 150px;
  z-index: 9999;
}


</style>